---
name: Patterns/Home cards
slug: home-cards
icon: CategoriesMajor
keywords:
  - home cards
  - insights
  - milestones
---

# Home cards

Home cards make actionable recommendations based on data from the merchant’s store, or give merchants feedback about their store’s performance.

Home cards should:

- track progress and give feedback
- teach and educate
- inspire and motivate
- be data-driven and use data from the merchant’s store

---

## Home card types

When choosing a home card type, think about the simplest way to present your message. For example, if the goal of the card is to inform merchants about holiday shipping deadlines, then a table is probably the best way to present this information. Alternatively, if your goal is to recognize merchant success, consider using a large illustration with some encouraging content.

### Simple card

<div class="Annotated">
  <div class="Annotated__Text">
    <p>Use when:</p>
    <ul>
      <li>
        you have one data point or recommendation, and one action. Use of the “Learn more” link is optional.  
      </li>
    </ul>
  </div>
<div class="Annotated__Media">
<div class="Image Image--border">

![Simple Home card encouraging the merchant to add or learn more about an advertising campaign](/public_images/home-card-page/simple-home-card@2x.png)

</div>
</div>
</div>

### Action-list card

<div class="Annotated">
  <div class="Annotated__Text">
    <p>Use when:</p>
    <ul>
      <li>
        you have one data point and a series of related actions
      </li>
    </ul>
  </div>
<div class="Annotated__Media">
<div class="Image Image--border">

![Action-list home card showing several suggested discounts the merchant can add, and prompting them to create their own](/public_images/home-card-page/action-list-home-card@2x.png)

</div>
</div>
</div>

### Table card

<div class="Annotated">
  <div class="Annotated__Text">
    <p>Use when:</p>
    <ul>
      <li>
        you have more than one data point but one action
      </li>
    </ul>
  </div>
<div class="Annotated__Media">
<div class="Image Image--border">

![Table card showing shipping services and the holiday dates the merchant can expect for each, with a prompt to see unfulfilled orders](/public_images/home-card-page/table-home-card@2x.png)

</div>
</div>
</div>

### Large illustration card

<div class="Annotated">
  <div class="Annotated__Text">
    <p>Use when:</p>
    <ul>
      <li>
        you need to introduce an unfamiliar concept, or you want to recognize merchant success
      </li>
      <li>
        you want to announce a new Shopify feature
      </li>
    </ul>
  </div>
  <div class="Annotated__Media">
  <div class="Image Image--border">

![Large illustration card encouraging and prompting the merchant to set up gift cards for the holidays](/public_images/home-card-page/large-illustration-home-card@2x.png)

</div>
</div>  
</div>

### Graph card

<div class="Annotated">
  <div class="Annotated__Text">
    <p>Use when:</p>
    <ul>
      <li>you need to show trends over time or compare two datasets</li>
    </ul>
  </div>
<div class="Annotated__Media">
<div class="Image Image--border">

![Graph card showing an upward trend in traffic to the merchant’s store from a social media post](/public_images/home-card-page/graph-home-card@2x.png)

</div>
</div>
</div>

### Video card

<div class="Annotated">
  <div class="Annotated__Text">
    <p>Use when:</p>
    <ul>
      <li>
        you need to communicate an unfamiliar concept or idea, or explain a complex task
      </li>
    </ul>
  </div>
<div class="Annotated__Media">
<div class="Image Image--border">

![Video card showing a video introducing an app, with a call to action to add it to the merchant’s store](/public_images/home-card-page/video-home-card@2x.png)

</div>
</div>
</div>

### Blog card

<div class="Annotated">
  <div class="Annotated__Text">
    <p>Use when:</p>
    <ul>
      <li>
        you need to recommend a helpful <a href="https://www.shopify.com/blog">Shopify blog post</a> based on a merchant’s previous activity
      </li>
    </ul>
  </div>
<div class="Annotated__Media">
  <div class="Image Image--border">

![Blog card showing a short description and link for a blog post relevant to the merchant’s experience](/public_images/home-card-page/blog-home-card@2x.png)

</div>
</div>
</div>

### Comparison card

<div class="Annotated">
  <div class="Annotated__Text">
    <p>Use when:</p>
    <ul>
      <li>
        you need to compare two data points
      </li>
    </ul>
  </div>
<div class="Annotated__Media">
  <div class="Image Image--border">

![Comparison card showing a brief description of a specific data point, with a comparison between the merchant’s data and an industry standard](/public_images/home-card-page/comparison-home-card@2x.png)

</div>
</div>
</div>

---

## Content

In general, home card content should follow this format:

- The **heading** should clearly state the merchant benefit or primary data point. Keep headings to a single sentence fragment and don’t use punctuation at the end.
- **Body** content should explain the value or significance of the information in the heading, and provide next steps. Body content should be concise and no longer than two sentences.
- The **primary call-to-action** should be clear, predictable, and actionable. A merchant should anticipate where the [call-to-action button](/content/actionable-language#section-buttons) takes them. Call-to-action buttons are action-led (verb + noun format), and shouldn’t exceed 34 characters in length.
- A **secondary call-to-action** links to a [Shopify Help Center](https://help.shopify.com/) article or a [Shopify Blog](https://www.shopify.com/blog) post. Include a secondary action whenever educational content is available for the topic of the home card. The button content is always “Learn more”.

---

## Voice and tone

A good home card prioritizes merchant needs over Shopify’s needs. Home cards are not advertisements, status updates, or [error messages](/patterns-and-guides/error-messages).

The tone changes depending on the context or situation of a card, but it should always be empathetic. For example, for a message about a negative situation, the tone should be considerate and encouraging, with a recommended action on how to fix it.

### Positive situation

<!-- usagelist -->

#### Do

Recognize milestones that merchants might find significant.

_**Congratulations on your 1st order** <br />
Sarah Rodriguez bought Rainbow Unicorn Plushie._

_**People are subscribing to your mailing list** <br />
Your mailing list lets you contact customers or visitors who have shown an interest in your store. Reach out to them with exclusive offers or updates about your products._

#### Don’t

Don’t downplay or over-exaggerate details.

_**You have received your 10th order.** <br />_

_**Congratulations! You’ve received 4 orders today!** <br />
Fulfill them from your Orders page!_

<!-- end -->

### Neutral situation

<!-- usagelist -->

#### Do

Share important information or insights about the merchant’s business.

_**Visitors from these social sites are spending time in your store** <br />
Here’s how many pages they viewed and how long they stayed._

#### Don’t

Don’t emphasize what Shopify can do for the merchant. Focus on the merchant benefit instead.

_**Use Shopify Payments!** <br />
We make it easy to accept payments online and won’t charge you any transaction fees._

_**Shopify Capital is offering you up to \$10,000 in funding** <br />
It’s easy to apply and it’ll help your business grow!_

<!-- end -->

### Negative situation

<!-- usagelist -->

#### Do

Be considerate with sensitive information and offer merchants solutions if something went wrong.

_**Some of your visitors can’t find what they’re looking for** <br />
You might want to add product descriptions to help them out._

#### Don’t

Don’t blame the merchant or only offer impractical or costly solutions.

_**Your shipping rates are high compared to similar stores** <br />
Save money on shipping labels with Shopify Shipping._

_**Sales are down this week** <br />
Consider creating a marketing campaign to promote your products._

<!-- end -->
